/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_5jcCApEf);
  numBytes += sLine_init(&sLine_qm8m5gDe);
  numBytes += sLine_init(&sLine_unH5Myry);
  numBytes += sLine_init(&sLine_ZsYXGwkv);
  numBytes += sLine_init(&sLine_1ZCyWpVg);
  numBytes += sLine_init(&sLine_AKC5mSE6);
  numBytes += sLine_init(&sLine_2FKyCnGO);
  numBytes += sLine_init(&sLine_FbADPKTg);
  numBytes += sLine_init(&sLine_g0YuB3kR);
  numBytes += sLine_init(&sLine_M6PvAsDo);
  numBytes += sLine_init(&sLine_7G4Uxoi1);
  numBytes += sLine_init(&sLine_mCgeeVul);
  numBytes += sEnv_init(&sEnv_fpIb2OSK, 512, 256);
  numBytes += sEnv_init(&sEnv_Yqs5pbC7, 512, 256);
  numBytes += sLine_init(&sLine_jaeqO6PY);
  numBytes += sLine_init(&sLine_pPPKhrXm);
  numBytes += sLine_init(&sLine_AsEcxRWE);
  numBytes += sLine_init(&sLine_JDHzuh9z);
  numBytes += sLine_init(&sLine_opnZKI6I);
  numBytes += sLine_init(&sLine_twfAAmBA);
  numBytes += sLine_init(&sLine_grijgBH0);
  numBytes += sLine_init(&sLine_6SGdDRsY);
  numBytes += sLine_init(&sLine_CXwqNeXC);
  numBytes += sLine_init(&sLine_iD3Cgxy8);
  numBytes += sLine_init(&sLine_b6lp1OkZ);
  numBytes += sLine_init(&sLine_FkxRkBNl);
  numBytes += sLine_init(&sLine_E50Yu6FV);
  numBytes += sLine_init(&sLine_h0NA9Mtq);
  numBytes += sLine_init(&sLine_Bu19A7MV);
  numBytes += sLine_init(&sLine_xAyqSPDd);
  numBytes += sLine_init(&sLine_m277kHjE);
  numBytes += sLine_init(&sLine_tOuRs9kN);
  numBytes += sEnv_init(&sEnv_WKXi9TwH, 512, 256);
  numBytes += sEnv_init(&sEnv_0sK5w4wG, 512, 256);
  numBytes += sLine_init(&sLine_3xpmYri3);
  numBytes += sLine_init(&sLine_05SrbTwi);
  numBytes += sLine_init(&sLine_S1qk00rD);
  numBytes += sLine_init(&sLine_RF1tvn45);
  numBytes += sLine_init(&sLine_uogaPPyu);
  numBytes += sLine_init(&sLine_jClkyQnk);
  numBytes += sLine_init(&sLine_b66ZQ8df);
  numBytes += sLine_init(&sLine_NkC5VASB);
  numBytes += cVar_init_f(&cVar_ueRu52EZ, 0.0f);
  numBytes += cVar_init_f(&cVar_KnsQc73K, 0.0f);
  numBytes += cVar_init_f(&cVar_rWSvUvJR, 0.0f);
  numBytes += cVar_init_f(&cVar_zxWubY4b, 0.0f);
  numBytes += cVar_init_f(&cVar_FiDcwNqc, 0.0f);
  numBytes += cVar_init_f(&cVar_5N3zIEKB, 1.0f);
  numBytes += cVar_init_f(&cVar_RPYnKNPD, 0.0f);
  numBytes += cVar_init_f(&cVar_bg6r1Mlc, 0.0f);
  numBytes += cIf_init(&cIf_whuQm2J3, false);
  numBytes += cIf_init(&cIf_LsUU7wFk, false);
  numBytes += cDelay_init(this, &cDelay_Avm0HojQ, 10.0f);
  numBytes += cIf_init(&cIf_vinIEXn2, false);
  numBytes += cIf_init(&cIf_Mvtr3PEa, false);
  numBytes += cDelay_init(this, &cDelay_vJHQFBB5, 10.0f);
  numBytes += cIf_init(&cIf_QpQ6n2Ni, false);
  numBytes += cIf_init(&cIf_j8FgIcB0, false);
  numBytes += cDelay_init(this, &cDelay_MgpkhtUP, 10.0f);
  numBytes += cIf_init(&cIf_7j1ksyKU, false);
  numBytes += cIf_init(&cIf_8tdlBqTP, false);
  numBytes += cDelay_init(this, &cDelay_2G8NeMvF, 10.0f);
  numBytes += cIf_init(&cIf_69bZqd13, false);
  numBytes += cIf_init(&cIf_iOC8kLCE, false);
  numBytes += cDelay_init(this, &cDelay_nrsLxmuK, 10.0f);
  numBytes += cIf_init(&cIf_7XO808uK, false);
  numBytes += cIf_init(&cIf_39JBtTg0, false);
  numBytes += cDelay_init(this, &cDelay_iduscC1N, 10.0f);
  numBytes += cIf_init(&cIf_kk8UdfWz, false);
  numBytes += cIf_init(&cIf_DDGH24v1, false);
  numBytes += cDelay_init(this, &cDelay_sL9f5Rpy, 10.0f);
  numBytes += cIf_init(&cIf_lqkfZYL7, false);
  numBytes += cIf_init(&cIf_pLrTgceW, false);
  numBytes += cDelay_init(this, &cDelay_4oTVF4LH, 10.0f);
  numBytes += cIf_init(&cIf_qdkdK3ii, false);
  numBytes += cIf_init(&cIf_RoL8alxQ, false);
  numBytes += cDelay_init(this, &cDelay_ebdQXVz9, 10.0f);
  numBytes += cIf_init(&cIf_2mLkpL6Q, false);
  numBytes += cIf_init(&cIf_3dymdiCC, false);
  numBytes += cDelay_init(this, &cDelay_etw72P6j, 10.0f);
  numBytes += cIf_init(&cIf_cMpsWxaR, false);
  numBytes += cIf_init(&cIf_2eruVHNc, false);
  numBytes += cDelay_init(this, &cDelay_hUJwe1Ez, 10.0f);
  numBytes += cIf_init(&cIf_pkIMrGAD, false);
  numBytes += cIf_init(&cIf_2Aungl88, false);
  numBytes += cDelay_init(this, &cDelay_zYFeGJnE, 10.0f);
  numBytes += sVarf_init(&sVarf_QLiWqu70, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qtp6Fi3G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e7FF7qbI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VnOoW83m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O3G8DFMS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aLINNtPN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iXf9228u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZIzsDeZs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OGjMnBvc, 0.0f);
  numBytes += cSlice_init(&cSlice_EQN2iIx6, 1, -1);
  numBytes += cVar_init_f(&cVar_tzerhe1r, 1.0f);
  numBytes += cSlice_init(&cSlice_0p7gcO1j, 1, -1);
  numBytes += cVar_init_f(&cVar_N5j3H27x, 0.0f);
  numBytes += cSlice_init(&cSlice_PkFtOzuK, 1, -1);
  numBytes += cVar_init_f(&cVar_j1y9B4nM, 512.0f);
  numBytes += cSlice_init(&cSlice_0w1awwct, 1, -1);
  numBytes += cVar_init_f(&cVar_GyduUREU, 1.0f);
  numBytes += cSlice_init(&cSlice_EA07qoMY, 1, -1);
  numBytes += cVar_init_f(&cVar_mkyLEoXc, 1.0f);
  numBytes += cDelay_init(this, &cDelay_0vQT4E1P, 20.0f);
  numBytes += cVar_init_f(&cVar_Cy1q7TjI, 0.0f);
  numBytes += cIf_init(&cIf_53izsXur, false);
  numBytes += cIf_init(&cIf_7Dp6UWEC, false);
  numBytes += cBinop_init(&cBinop_bDENf0HM, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Xe4GF1VV, 1, -1);
  numBytes += cVar_init_f(&cVar_6bSfCNEI, 0.0f);
  numBytes += sVarf_init(&sVarf_raCtatpO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_twthQ0e3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1UnSnOVF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AfmcOO4c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B1Zq4XXh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RpZMn31x, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_U2lD3izh, 0.0f);
  numBytes += cVar_init_f(&cVar_TnsIxR28, 0.0f);
  numBytes += cIf_init(&cIf_z2jKuQ07, false);
  numBytes += cIf_init(&cIf_7Woc2a6P, false);
  numBytes += cDelay_init(this, &cDelay_fmfCpca3, 10.0f);
  numBytes += cIf_init(&cIf_k6gqzZj3, false);
  numBytes += cIf_init(&cIf_Hn0viT1b, false);
  numBytes += cDelay_init(this, &cDelay_PRsZeYoe, 10.0f);
  numBytes += cIf_init(&cIf_2EugpMVG, false);
  numBytes += cIf_init(&cIf_tlFFXIBk, false);
  numBytes += cDelay_init(this, &cDelay_PxEgk76h, 10.0f);
  numBytes += cIf_init(&cIf_Ogl7kYP6, false);
  numBytes += cIf_init(&cIf_dADZvmE3, false);
  numBytes += cDelay_init(this, &cDelay_VrFSFz8f, 10.0f);
  numBytes += cIf_init(&cIf_pqSif6jp, false);
  numBytes += cIf_init(&cIf_1s7HogMQ, false);
  numBytes += cDelay_init(this, &cDelay_Q1Vt2kf2, 10.0f);
  numBytes += cIf_init(&cIf_1PUZjwqO, false);
  numBytes += cIf_init(&cIf_T2Z3Jl4Q, false);
  numBytes += cDelay_init(this, &cDelay_5bsOVp4a, 10.0f);
  numBytes += cIf_init(&cIf_ZGHktbT2, false);
  numBytes += cIf_init(&cIf_QAQ0Y3sX, false);
  numBytes += cDelay_init(this, &cDelay_BXIs6Um1, 10.0f);
  numBytes += cIf_init(&cIf_ss3IDaEo, false);
  numBytes += cIf_init(&cIf_rR8kFG4Z, false);
  numBytes += cDelay_init(this, &cDelay_HIol2BIL, 10.0f);
  numBytes += cIf_init(&cIf_SKJyFIf6, false);
  numBytes += cIf_init(&cIf_ashvqBEk, false);
  numBytes += cDelay_init(this, &cDelay_wBMWUAya, 10.0f);
  numBytes += cIf_init(&cIf_9cMjPQbp, false);
  numBytes += cIf_init(&cIf_BfHCpLYZ, false);
  numBytes += cDelay_init(this, &cDelay_NX2cGOzM, 10.0f);
  numBytes += cIf_init(&cIf_eoco4iaO, false);
  numBytes += cIf_init(&cIf_7GZGFOLd, false);
  numBytes += cDelay_init(this, &cDelay_rdzqxbVj, 10.0f);
  numBytes += cIf_init(&cIf_HgWi07nZ, false);
  numBytes += cIf_init(&cIf_CaEE9KF5, false);
  numBytes += cDelay_init(this, &cDelay_ZljG7yEF, 10.0f);
  numBytes += sVarf_init(&sVarf_CwONgLc8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rHNRWURj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tHF9kVMD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oRCHDZvE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jquWLlyK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GXKA1aMo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w522ofzX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lJgHGFCD, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HfQKxZ3l, 0.0f);
  numBytes += cSlice_init(&cSlice_Jw678xns, 1, -1);
  numBytes += cVar_init_f(&cVar_xFTSuK4Z, 1.0f);
  numBytes += cSlice_init(&cSlice_HSUDkxEp, 1, -1);
  numBytes += cVar_init_f(&cVar_KoCtah1a, 0.0f);
  numBytes += cSlice_init(&cSlice_QZsSu8Ah, 1, -1);
  numBytes += cVar_init_f(&cVar_rULWSr8v, 512.0f);
  numBytes += cSlice_init(&cSlice_OWB8ImNJ, 1, -1);
  numBytes += cVar_init_f(&cVar_liiJZTgr, 1.0f);
  numBytes += cSlice_init(&cSlice_Vv64dhFF, 1, -1);
  numBytes += cVar_init_f(&cVar_wumONHL6, 1.0f);
  numBytes += cDelay_init(this, &cDelay_e3lSyFhs, 20.0f);
  numBytes += cVar_init_f(&cVar_RVXHcNnU, 0.0f);
  numBytes += cIf_init(&cIf_0vwNbSCa, false);
  numBytes += cIf_init(&cIf_4opzxpGn, false);
  numBytes += cBinop_init(&cBinop_Vyq8q1bN, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_gldKzvQj, 1, -1);
  numBytes += cVar_init_f(&cVar_LmzjxJam, 0.0f);
  numBytes += sVarf_init(&sVarf_bzolRMvT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OFAY6Mru, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2Olaf5HQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cl17mMD4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oAf6O6Iv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GhVr3YA8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JU3Qrley, 0.0f);
  numBytes += sVarf_init(&sVarf_7RXa46KR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jSYWnGIk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_99DQNRYX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6HbaqL7L, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_fpIb2OSK);
  sEnv_free(&sEnv_Yqs5pbC7);
  sEnv_free(&sEnv_WKXi9TwH);
  sEnv_free(&sEnv_0sK5w4wG);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KPXEMLGP_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Hb9GH1I5_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WMKvA9k8_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ajHY46CJ_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AACsnfBi_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OaBnFh5K_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UCJJferg_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ua9EI8iG_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ny7LPr0r_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VGH3vUal_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bgs5Mi9t_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xzrbp2d3_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cCvF3QOL_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e71oun4c_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6AI8yAu8_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G0sCHPJR_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NIUXCOTB_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HAL1OlEo_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dBr6dkqI_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VFDhbrP6_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Geara375_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_ueRu52EZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k5ATjlWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_20LknxBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GMwepJKG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GMwepJKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_eEP2exrt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eEP2exrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_97SLrZ9r_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_97SLrZ9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mxlqi4f6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4iUzowt9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4iUzowt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EQkm4hCI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_mxlqi4f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7oSdy4z1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7oSdy4z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_06QTKHe5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EQkm4hCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bjj1GJPc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bjj1GJPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7uskdXw8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_06QTKHe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BbiurFHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_7uskdXw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_79AVFyqZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_KnsQc73K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rU3xHNMY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_rWSvUvJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QmRMmzij_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_zxWubY4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TsonaUlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_FiDcwNqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gL1nKRDT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_5N3zIEKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0jnJ2Qkh_sendMessage);
  cMsg_02SWfP1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_0jnJ2Qkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5N3zIEKB, 1, m, &cVar_5N3zIEKB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_L8irQR4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tbdeHPtC_sendMessage(_c, 0, m);
  cMsg_JaAJ1ZqX_sendMessage(_c, 0, m);
  cMsg_EGziEL7D_sendMessage(_c, 0, m);
  cMsg_DXMXOQL6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_RPYnKNPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F228BVDG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_bg6r1Mlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r5zibbpk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_pdUP3NX2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jc8MKGQS_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OyZnkrCe_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_01tiB45f_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LSNZb6VT_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WfySi0L4_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3UhTmoY4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_jc8MKGQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rt1N4nxM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_OyZnkrCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cbh9tg1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_01tiB45f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_479F8dps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_LSNZb6VT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nSlIO0lV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_WfySi0L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FvvTAAwF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_3UhTmoY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IFLrbSlA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_whuQm2J3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FhBqo1Ox_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_LsUU7wFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wy0lVQB8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_QtVCvIR7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kIsDFy2j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kIsDFy2j_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Avm0HojQ, 1, m, &cDelay_Avm0HojQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BVXpxxCb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Avm0HojQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Avm0HojQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_whuQm2J3, 0, m, &cIf_whuQm2J3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kIsDFy2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Avm0HojQ, 0, m, &cDelay_Avm0HojQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BVXpxxCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Avm0HojQ, 0, m, &cDelay_Avm0HojQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RH7tWYwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PcTzrZAe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sSQw2LkN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_46X3x3tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bv8jrr4p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T4K2iOqQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T4K2iOqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QtVCvIR7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Bv8jrr4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_whuQm2J3, 1, m, &cIf_whuQm2J3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PcTzrZAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LsUU7wFk, 1, m, &cIf_LsUU7wFk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sSQw2LkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LsUU7wFk, 0, m, &cIf_LsUU7wFk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wy0lVQB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZsYXGwkv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_FhBqo1Ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZsYXGwkv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vinIEXn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NZv8vCrp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Mvtr3PEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TYoyPEmD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_yOJWhdT8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gFrtgiF8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gFrtgiF8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vJHQFBB5, 1, m, &cDelay_vJHQFBB5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_miEwD6gO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vJHQFBB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vJHQFBB5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vinIEXn2, 0, m, &cIf_vinIEXn2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gFrtgiF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vJHQFBB5, 0, m, &cDelay_vJHQFBB5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_miEwD6gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vJHQFBB5, 0, m, &cDelay_vJHQFBB5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aW9Z8Ic9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rQF8sjGA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yNmT9saM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ESDibQ10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H9x5CDwx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OfaYxKMd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_H9x5CDwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vinIEXn2, 1, m, &cIf_vinIEXn2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OfaYxKMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yOJWhdT8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_rQF8sjGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mvtr3PEa, 1, m, &cIf_Mvtr3PEa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yNmT9saM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mvtr3PEa, 0, m, &cIf_Mvtr3PEa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TYoyPEmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2FKyCnGO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NZv8vCrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2FKyCnGO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_QpQ6n2Ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nwp4KbLC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_j8FgIcB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F4NAM5LM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_nIcsziVM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N6RV2pT4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N6RV2pT4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MgpkhtUP, 1, m, &cDelay_MgpkhtUP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YXOpAl7Q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_MgpkhtUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MgpkhtUP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QpQ6n2Ni, 0, m, &cIf_QpQ6n2Ni_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_N6RV2pT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MgpkhtUP, 0, m, &cDelay_MgpkhtUP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YXOpAl7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MgpkhtUP, 0, m, &cDelay_MgpkhtUP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HNvcT8jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W9YpEAdq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IufflVnN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yzc4ArMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SNUuejIh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HlX1Wrw2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HlX1Wrw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nIcsziVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_SNUuejIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QpQ6n2Ni, 1, m, &cIf_QpQ6n2Ni_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W9YpEAdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j8FgIcB0, 1, m, &cIf_j8FgIcB0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IufflVnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j8FgIcB0, 0, m, &cIf_j8FgIcB0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_F4NAM5LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M6PvAsDo, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Nwp4KbLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M6PvAsDo, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7j1ksyKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_m2DvHRTR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_8tdlBqTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hXhedAwk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_JL7S0TQI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sdOCN5yh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sdOCN5yh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2G8NeMvF, 1, m, &cDelay_2G8NeMvF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zbsntu1a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_2G8NeMvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2G8NeMvF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7j1ksyKU, 0, m, &cIf_7j1ksyKU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sdOCN5yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2G8NeMvF, 0, m, &cDelay_2G8NeMvF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zbsntu1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2G8NeMvF, 0, m, &cDelay_2G8NeMvF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wAAuKrye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8EFEx1QJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SzJI0tzX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_U7oiwSjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_niVJ6TsU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kmog3Ky3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kmog3Ky3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JL7S0TQI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_niVJ6TsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7j1ksyKU, 1, m, &cIf_7j1ksyKU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SzJI0tzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8tdlBqTP, 0, m, &cIf_8tdlBqTP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8EFEx1QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8tdlBqTP, 1, m, &cIf_8tdlBqTP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hXhedAwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1ZCyWpVg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_m2DvHRTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1ZCyWpVg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_69bZqd13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_skbcV5rX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_iOC8kLCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rl9kTUyg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_JbBwK9Jm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OvBpj86k_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OvBpj86k_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nrsLxmuK, 1, m, &cDelay_nrsLxmuK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iUQ9f5KB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_nrsLxmuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nrsLxmuK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_69bZqd13, 0, m, &cIf_69bZqd13_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OvBpj86k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nrsLxmuK, 0, m, &cDelay_nrsLxmuK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iUQ9f5KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nrsLxmuK, 0, m, &cDelay_nrsLxmuK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_E3NkyVEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CdqTXATy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QmCNOw8Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DxvPMy46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pN2LszuZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LqY3qfYE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LqY3qfYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JbBwK9Jm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_pN2LszuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_69bZqd13, 1, m, &cIf_69bZqd13_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QmCNOw8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iOC8kLCE, 0, m, &cIf_iOC8kLCE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CdqTXATy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iOC8kLCE, 1, m, &cIf_iOC8kLCE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rl9kTUyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FbADPKTg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_skbcV5rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FbADPKTg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7XO808uK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nZFUX1bD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_39JBtTg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ACBK6r8a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_YYrNBFTm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EbSbfqub_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EbSbfqub_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_iduscC1N, 1, m, &cDelay_iduscC1N_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xoALNfuD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_iduscC1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iduscC1N, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7XO808uK, 0, m, &cIf_7XO808uK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EbSbfqub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iduscC1N, 0, m, &cDelay_iduscC1N_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xoALNfuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iduscC1N, 0, m, &cDelay_iduscC1N_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DDUCw56S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yzS0sbLo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vmqmn8DO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CXkBqr8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JvG14DZy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wRJyEYkC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wRJyEYkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YYrNBFTm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JvG14DZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7XO808uK, 1, m, &cIf_7XO808uK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vmqmn8DO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_39JBtTg0, 0, m, &cIf_39JBtTg0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yzS0sbLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_39JBtTg0, 1, m, &cIf_39JBtTg0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ACBK6r8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7G4Uxoi1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nZFUX1bD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7G4Uxoi1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_kk8UdfWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NrVGLS7n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DDGH24v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wdUiaN1I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_BgtHgBxJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UO5UN4pN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UO5UN4pN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sL9f5Rpy, 1, m, &cDelay_sL9f5Rpy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cFEiVSba_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_sL9f5Rpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sL9f5Rpy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kk8UdfWz, 0, m, &cIf_kk8UdfWz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UO5UN4pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sL9f5Rpy, 0, m, &cDelay_sL9f5Rpy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cFEiVSba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sL9f5Rpy, 0, m, &cDelay_sL9f5Rpy_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2GaNt50w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_plwuQjrz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mmZ9Sc5b_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fFe0oV83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_30EJrgUj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Std09Aes_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_30EJrgUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kk8UdfWz, 1, m, &cIf_kk8UdfWz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Std09Aes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BgtHgBxJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_plwuQjrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DDGH24v1, 1, m, &cIf_DDGH24v1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mmZ9Sc5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DDGH24v1, 0, m, &cIf_DDGH24v1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wdUiaN1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AKC5mSE6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NrVGLS7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AKC5mSE6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_lqkfZYL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QZEh3a4v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_pLrTgceW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xpXB3O1Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_4SSiFenP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kv5veRma_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kv5veRma_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4oTVF4LH, 1, m, &cDelay_4oTVF4LH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z9Pz7QIf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4oTVF4LH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4oTVF4LH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lqkfZYL7, 0, m, &cIf_lqkfZYL7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kv5veRma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4oTVF4LH, 0, m, &cDelay_4oTVF4LH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z9Pz7QIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4oTVF4LH, 0, m, &cDelay_4oTVF4LH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cuNnDgyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EsaaYVcp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GiYN83bb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fqiaGDEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L2wH2Reg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GBuYjqgd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_L2wH2Reg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lqkfZYL7, 1, m, &cIf_lqkfZYL7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GBuYjqgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4SSiFenP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_EsaaYVcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pLrTgceW, 1, m, &cIf_pLrTgceW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GiYN83bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pLrTgceW, 0, m, &cIf_pLrTgceW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xpXB3O1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g0YuB3kR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QZEh3a4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g0YuB3kR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_qdkdK3ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s7riYDse_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_RoL8alxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wIdoiZ7u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_afsmqBKW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NIlUwjR3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NIlUwjR3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ebdQXVz9, 1, m, &cDelay_ebdQXVz9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3CnoZvT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ebdQXVz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ebdQXVz9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qdkdK3ii, 0, m, &cIf_qdkdK3ii_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NIlUwjR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ebdQXVz9, 0, m, &cDelay_ebdQXVz9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_r3CnoZvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ebdQXVz9, 0, m, &cDelay_ebdQXVz9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ztgJide4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B40ol3y2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KyvNmvCk_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BD8MVdte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rX4OtbS0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NJlWRyGJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NJlWRyGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_afsmqBKW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_rX4OtbS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qdkdK3ii, 1, m, &cIf_qdkdK3ii_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_B40ol3y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RoL8alxQ, 1, m, &cIf_RoL8alxQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KyvNmvCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RoL8alxQ, 0, m, &cIf_RoL8alxQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wIdoiZ7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mCgeeVul, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_s7riYDse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mCgeeVul, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2mLkpL6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TWm7bVQe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_3dymdiCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q88wVnb1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_AmoMDMOb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_S6YLhNbW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_S6YLhNbW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_etw72P6j, 1, m, &cDelay_etw72P6j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R5rEpj0C_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_etw72P6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_etw72P6j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2mLkpL6Q, 0, m, &cIf_2mLkpL6Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_S6YLhNbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_etw72P6j, 0, m, &cDelay_etw72P6j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_R5rEpj0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_etw72P6j, 0, m, &cDelay_etw72P6j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BXUvB7YE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jvHDP66R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Jg3U6ty_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7DKnhTCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lj3Cui7I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k4AmyKlE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_k4AmyKlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AmoMDMOb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Lj3Cui7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2mLkpL6Q, 1, m, &cIf_2mLkpL6Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3Jg3U6ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3dymdiCC, 0, m, &cIf_3dymdiCC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jvHDP66R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3dymdiCC, 1, m, &cIf_3dymdiCC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Q88wVnb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5jcCApEf, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TWm7bVQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5jcCApEf, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_cMpsWxaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BwcFn8eu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_2eruVHNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R7AnncyS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_4yP8675G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XamnJkre_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XamnJkre_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hUJwe1Ez, 1, m, &cDelay_hUJwe1Ez_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3hJ1upSU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_hUJwe1Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hUJwe1Ez, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cMpsWxaR, 0, m, &cIf_cMpsWxaR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XamnJkre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hUJwe1Ez, 0, m, &cDelay_hUJwe1Ez_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3hJ1upSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hUJwe1Ez, 0, m, &cDelay_hUJwe1Ez_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uQtFP5Qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_teagae7Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jsR6OmHt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hmhf6JHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rVGsd2P7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_brm6rSI0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_brm6rSI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4yP8675G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_rVGsd2P7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cMpsWxaR, 1, m, &cIf_cMpsWxaR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_teagae7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2eruVHNc, 1, m, &cIf_2eruVHNc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jsR6OmHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2eruVHNc, 0, m, &cIf_2eruVHNc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_R7AnncyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qm8m5gDe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BwcFn8eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qm8m5gDe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_pkIMrGAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iAtSiobL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_2Aungl88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qxxyt4ow_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_EQL5HhrW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_COO5baek_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_COO5baek_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zYFeGJnE, 1, m, &cDelay_zYFeGJnE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9dWhSpTb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_zYFeGJnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zYFeGJnE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pkIMrGAD, 0, m, &cIf_pkIMrGAD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_COO5baek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zYFeGJnE, 0, m, &cDelay_zYFeGJnE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9dWhSpTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zYFeGJnE, 0, m, &cDelay_zYFeGJnE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_45ohrOss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q7j4CUEl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HaA4ehkn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uSpmZkBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eAbpgIOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EODwyv4z_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EODwyv4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EQL5HhrW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_eAbpgIOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pkIMrGAD, 1, m, &cIf_pkIMrGAD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HaA4ehkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Aungl88, 0, m, &cIf_2Aungl88_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Q7j4CUEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Aungl88, 1, m, &cIf_2Aungl88_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qxxyt4ow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_unH5Myry, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iAtSiobL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_unH5Myry, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Rt1N4nxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_yLPNQtnI_sendMessage(_c, 0, m);
  cMsg_U98QvkYe_sendMessage(_c, 0, m);
  cMsg_e8nCqenV_sendMessage(_c, 0, m);
  cMsg_HgMSCB3c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Cbh9tg1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_yLPNQtnI_sendMessage(_c, 0, m);
  cMsg_xdYqZM1b_sendMessage(_c, 0, m);
  cMsg_7vg4VfYO_sendMessage(_c, 0, m);
  cMsg_fihf7DKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_479F8dps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_gOTe4nV3_sendMessage(_c, 0, m);
  cMsg_xdYqZM1b_sendMessage(_c, 0, m);
  cMsg_HgMSCB3c_sendMessage(_c, 0, m);
  cMsg_M1V8uR1V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_nSlIO0lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_gOTe4nV3_sendMessage(_c, 0, m);
  cMsg_EDOIOMbQ_sendMessage(_c, 0, m);
  cMsg_e8nCqenV_sendMessage(_c, 0, m);
  cMsg_rydzXbOB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_FvvTAAwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_3mIAQUyQ_sendMessage(_c, 0, m);
  cMsg_fihf7DKG_sendMessage(_c, 0, m);
  cMsg_f7tvDa0s_sendMessage(_c, 0, m);
  cMsg_e8nCqenV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_IFLrbSlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_3mIAQUyQ_sendMessage(_c, 0, m);
  cMsg_rydzXbOB_sendMessage(_c, 0, m);
  cMsg_xdYqZM1b_sendMessage(_c, 0, m);
  cMsg_ctdvYuE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TVP6SC4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_46X3x3tm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RH7tWYwr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hZOasOVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_46X3x3tm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RH7tWYwr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eCMj2p7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ESDibQ10_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aW9Z8Ic9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JS4osYbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ESDibQ10_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aW9Z8Ic9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XjtJfol6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yzc4ArMF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HNvcT8jq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XQDWHAW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yzc4ArMF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HNvcT8jq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yLPNQtnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_TVP6SC4u_sendMessage(_c, 0, m);
  cMsg_JS4osYbw_sendMessage(_c, 0, m);
  cMsg_XQDWHAW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gOTe4nV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_hZOasOVx_sendMessage(_c, 0, m);
  cMsg_eCMj2p7v_sendMessage(_c, 0, m);
  cMsg_XQDWHAW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_3mIAQUyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_hZOasOVx_sendMessage(_c, 0, m);
  cMsg_JS4osYbw_sendMessage(_c, 0, m);
  cMsg_XjtJfol6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bvaTsQKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U7oiwSjZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wAAuKrye_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XyihXx8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U7oiwSjZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wAAuKrye_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZsDcqOiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DxvPMy46_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E3NkyVEK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9wulQ4lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DxvPMy46_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E3NkyVEK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xjdRXRXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CXkBqr8R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DDUCw56S_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gLyTIJRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CXkBqr8R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DDUCw56S_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xdYqZM1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_XyihXx8z_sendMessage(_c, 0, m);
  cMsg_9wulQ4lx_sendMessage(_c, 0, m);
  cMsg_gLyTIJRA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_U98QvkYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_XyihXx8z_sendMessage(_c, 0, m);
  cMsg_ZsDcqOiD_sendMessage(_c, 0, m);
  cMsg_xjdRXRXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_EDOIOMbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_bvaTsQKd_sendMessage(_c, 0, m);
  cMsg_9wulQ4lx_sendMessage(_c, 0, m);
  cMsg_xjdRXRXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1FOknb7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7DKnhTCt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BXUvB7YE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1i9VjvS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7DKnhTCt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BXUvB7YE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rPrNgnXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hmhf6JHj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uQtFP5Qq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dIA9uS0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hmhf6JHj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uQtFP5Qq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JGzVEJhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uSpmZkBi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_45ohrOss_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Voyq458S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uSpmZkBi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_45ohrOss_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rydzXbOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_1FOknb7Z_sendMessage(_c, 0, m);
  cMsg_dIA9uS0j_sendMessage(_c, 0, m);
  cMsg_Voyq458S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fihf7DKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_1i9VjvS9_sendMessage(_c, 0, m);
  cMsg_rPrNgnXE_sendMessage(_c, 0, m);
  cMsg_Voyq458S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HgMSCB3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_1i9VjvS9_sendMessage(_c, 0, m);
  cMsg_dIA9uS0j_sendMessage(_c, 0, m);
  cMsg_JGzVEJhk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_b9mGvN4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fFe0oV83_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2GaNt50w_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eFwQGXce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fFe0oV83_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2GaNt50w_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yRYwAxZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fqiaGDEy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cuNnDgyE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8QMcLHrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fqiaGDEy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cuNnDgyE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LZm4XMgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BD8MVdte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ztgJide4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kCNIbFQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BD8MVdte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ztgJide4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_e8nCqenV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_eFwQGXce_sendMessage(_c, 0, m);
  cMsg_8QMcLHrg_sendMessage(_c, 0, m);
  cMsg_kCNIbFQI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7vg4VfYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_eFwQGXce_sendMessage(_c, 0, m);
  cMsg_yRYwAxZ2_sendMessage(_c, 0, m);
  cMsg_LZm4XMgm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ctdvYuE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_b9mGvN4N_sendMessage(_c, 0, m);
  cMsg_yRYwAxZ2_sendMessage(_c, 0, m);
  cMsg_kCNIbFQI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f7tvDa0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_bvaTsQKd_sendMessage(_c, 0, m);
  cMsg_ZsDcqOiD_sendMessage(_c, 0, m);
  cMsg_gLyTIJRA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_M1V8uR1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_b9mGvN4N_sendMessage(_c, 0, m);
  cMsg_8QMcLHrg_sendMessage(_c, 0, m);
  cMsg_LZm4XMgm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_OGjMnBvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bh4cKT12_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_nDBVp5zh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EQN2iIx6, 0, m, &cSlice_EQN2iIx6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kOMZdhE2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_EQN2iIx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ux2xxVdU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ux2xxVdU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_tzerhe1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ux2xxVdU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Ux2xxVdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VGH3vUal_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_NUiFwOKc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0p7gcO1j, 0, m, &cSlice_0p7gcO1j_sendMessage);
      break;
    }
    default: {
      cSwitchcase_suchLnRQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_0p7gcO1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ukFPVxnN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ukFPVxnN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_N5j3H27x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ukFPVxnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ukFPVxnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e71oun4c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_suchLnRQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PkFtOzuK, 0, m, &cSlice_PkFtOzuK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nDBVp5zh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_PkFtOzuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z7oL0QYY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z7oL0QYY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_j1y9B4nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z7oL0QYY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_z7oL0QYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ny7LPr0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_kOMZdhE2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0w1awwct, 0, m, &cSlice_0w1awwct_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qDs1JEYT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_0w1awwct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JwSJ1KAW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JwSJ1KAW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_GyduUREU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JwSJ1KAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_JwSJ1KAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cCvF3QOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_qDs1JEYT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EA07qoMY, 0, m, &cSlice_EA07qoMY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_USXMSQTP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_EA07qoMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eHZZ1BfW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eHZZ1BfW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_mkyLEoXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eHZZ1BfW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_eHZZ1BfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xzrbp2d3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_EMX6K1HL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KwC6XDEX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KwC6XDEX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0vQT4E1P, 1, m, &cDelay_0vQT4E1P_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z7J7DYZq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_0vQT4E1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0vQT4E1P, m);
  cMsg_c9ztfHGO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KwC6XDEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0vQT4E1P, 0, m, &cDelay_0vQT4E1P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z7J7DYZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0vQT4E1P, 0, m, &cDelay_0vQT4E1P_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_Cy1q7TjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bDENf0HM, HV_BINOP_SUBTRACT, 0, m, &cBinop_bDENf0HM_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_53izsXur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s7ZpgYBk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7Dp6UWEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s7ZpgYBk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_fpIb2OSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cy1q7TjI, 0, m, &cVar_Cy1q7TjI_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_Yqs5pbC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sHiMjg7p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4oOCvZV0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cd5fCglp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bDENf0HM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gFHFHxJg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gFHFHxJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fiLFNhVn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fiLFNhVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_4Ocm2kW9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DkWwgKbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_06gHCszx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qX6kkZzX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qX6kkZzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6nu1DiHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_06gHCszx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_53izsXur, 1, m, &cIf_53izsXur_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HOuYU3Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Dp6UWEC, 1, m, &cIf_7Dp6UWEC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6nu1DiHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_53izsXur, 0, m, &cIf_53izsXur_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4Ocm2kW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Dp6UWEC, 0, m, &cIf_7Dp6UWEC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4oOCvZV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bDENf0HM, HV_BINOP_SUBTRACT, 1, m, &cBinop_bDENf0HM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sHiMjg7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_cd5fCglp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cy1q7TjI, 0, m, &cVar_Cy1q7TjI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_s7ZpgYBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jaeqO6PY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_USXMSQTP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xe4GF1VV, 0, m, &cSlice_Xe4GF1VV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Xe4GF1VV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qZxyFwc0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qZxyFwc0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_6bSfCNEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qZxyFwc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_qZxyFwc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Bgs5Mi9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_F228BVDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_twfAAmBA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_r5zibbpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JDHzuh9z, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_rJvL0cMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bg6r1Mlc, 0, m, &cVar_bg6r1Mlc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Bh4cKT12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_opnZKI6I, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_qRGERANE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EMX6K1HL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NgSIIC91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R9vuA039_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_c9ztfHGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pPPKhrXm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_R9vuA039_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pPPKhrXm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XBQXZXUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_AcBGs1qP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AcBGs1qP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3QfYdilt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_3QfYdilt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AsEcxRWE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_U2lD3izh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uW33wTif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_TnsIxR28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XQr0yMjF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_NOLsKhWF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Fu0IhVl_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6CJ9G9HN_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7f6JgNn9_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KrQ1MoFp_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oT6W9rbm_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YIu5YWxC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_6Fu0IhVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n9H65p91_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_6CJ9G9HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nZwJQBuq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_7f6JgNn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EEjfcewk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_KrQ1MoFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DkFWRrye_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_oT6W9rbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D6C9y4Tl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_YIu5YWxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CL7aH9XX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_z2jKuQ07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2SJLcdEv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7Woc2a6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MpwiVMeb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_thcmhWIM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lS2YRols_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lS2YRols_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fmfCpca3, 1, m, &cDelay_fmfCpca3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zNLzqNfY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_fmfCpca3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fmfCpca3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_z2jKuQ07, 0, m, &cIf_z2jKuQ07_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lS2YRols_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fmfCpca3, 0, m, &cDelay_fmfCpca3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zNLzqNfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fmfCpca3, 0, m, &cDelay_fmfCpca3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6y2rH5YX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hJVA5EZH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MabhfXW9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iutyrF6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ApSMG7a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P5H9nI3s_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_P5H9nI3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_thcmhWIM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_4ApSMG7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z2jKuQ07, 1, m, &cIf_z2jKuQ07_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MabhfXW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Woc2a6P, 0, m, &cIf_7Woc2a6P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hJVA5EZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Woc2a6P, 1, m, &cIf_7Woc2a6P_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MpwiVMeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iD3Cgxy8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2SJLcdEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iD3Cgxy8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_k6gqzZj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BnNQXE07_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Hn0viT1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WJ4DXz0O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_aA7Hq4Xv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DG0nV6Ww_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DG0nV6Ww_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PRsZeYoe, 1, m, &cDelay_PRsZeYoe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XqzGfu8a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PRsZeYoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PRsZeYoe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_k6gqzZj3, 0, m, &cIf_k6gqzZj3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DG0nV6Ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PRsZeYoe, 0, m, &cDelay_PRsZeYoe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XqzGfu8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PRsZeYoe, 0, m, &cDelay_PRsZeYoe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8RyxAJUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MfJAsjin_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WN8AwuA6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NFddaLx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6zq9EUj6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FximnKP8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FximnKP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aA7Hq4Xv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_6zq9EUj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k6gqzZj3, 1, m, &cIf_k6gqzZj3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WN8AwuA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hn0viT1b, 0, m, &cIf_Hn0viT1b_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MfJAsjin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hn0viT1b, 1, m, &cIf_Hn0viT1b_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WJ4DXz0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E50Yu6FV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BnNQXE07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E50Yu6FV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2EugpMVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UapAhSPD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tlFFXIBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g4K8ApzR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_0axEAo3j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Tg0t0occ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Tg0t0occ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PxEgk76h, 1, m, &cDelay_PxEgk76h_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vshezpOh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PxEgk76h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PxEgk76h, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2EugpMVG, 0, m, &cIf_2EugpMVG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Tg0t0occ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PxEgk76h, 0, m, &cDelay_PxEgk76h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vshezpOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PxEgk76h, 0, m, &cDelay_PxEgk76h_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1Ni0Aie2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zZCHzVcl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qShnBNbx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_S60xmEQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CVnGpbNT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jj0YEh8L_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CVnGpbNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2EugpMVG, 1, m, &cIf_2EugpMVG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Jj0YEh8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0axEAo3j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_qShnBNbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tlFFXIBk, 0, m, &cIf_tlFFXIBk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zZCHzVcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tlFFXIBk, 1, m, &cIf_tlFFXIBk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_g4K8ApzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xAyqSPDd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_UapAhSPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xAyqSPDd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Ogl7kYP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_929VIGsD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_dADZvmE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HZBPmcl0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3IiSeQUn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tJnaLDnQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tJnaLDnQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VrFSFz8f, 1, m, &cDelay_VrFSFz8f_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TNE407sb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_VrFSFz8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VrFSFz8f, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ogl7kYP6, 0, m, &cIf_Ogl7kYP6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tJnaLDnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VrFSFz8f, 0, m, &cDelay_VrFSFz8f_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TNE407sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VrFSFz8f, 0, m, &cDelay_VrFSFz8f_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8ny8LeZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5w31E27p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YFZUDA4j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Wrmtem1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Me6Ths4R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JuaNHIET_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Me6Ths4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ogl7kYP6, 1, m, &cIf_Ogl7kYP6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JuaNHIET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3IiSeQUn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_5w31E27p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dADZvmE3, 1, m, &cIf_dADZvmE3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YFZUDA4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dADZvmE3, 0, m, &cIf_dADZvmE3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HZBPmcl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b6lp1OkZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_929VIGsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b6lp1OkZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_pqSif6jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6sr0FZRX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_1s7HogMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3E3I9d6R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_zFr2z5DM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cWjyNQ2k_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cWjyNQ2k_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q1Vt2kf2, 1, m, &cDelay_Q1Vt2kf2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2fhbjhYp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Q1Vt2kf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q1Vt2kf2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pqSif6jp, 0, m, &cIf_pqSif6jp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cWjyNQ2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q1Vt2kf2, 0, m, &cDelay_Q1Vt2kf2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2fhbjhYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q1Vt2kf2, 0, m, &cDelay_Q1Vt2kf2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PsMJsESe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aTN2fpc2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NGrJ2i1x_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dnShgukO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YCHLy0sb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i6Q3FGkn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YCHLy0sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pqSif6jp, 1, m, &cIf_pqSif6jp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_i6Q3FGkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zFr2z5DM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_aTN2fpc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1s7HogMQ, 1, m, &cIf_1s7HogMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NGrJ2i1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1s7HogMQ, 0, m, &cIf_1s7HogMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3E3I9d6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h0NA9Mtq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_6sr0FZRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h0NA9Mtq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_1PUZjwqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p30HvBjm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_T2Z3Jl4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zxdeJP1R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_OVVb45TH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fUniW083_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fUniW083_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5bsOVp4a, 1, m, &cDelay_5bsOVp4a_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S79g1s9I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5bsOVp4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5bsOVp4a, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1PUZjwqO, 0, m, &cIf_1PUZjwqO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fUniW083_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5bsOVp4a, 0, m, &cDelay_5bsOVp4a_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_S79g1s9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5bsOVp4a, 0, m, &cDelay_5bsOVp4a_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KL9vM41Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Yupq4Zf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CPA0wDgb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fuktE4xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iiO56laC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NWk1dYPi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NWk1dYPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OVVb45TH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_iiO56laC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1PUZjwqO, 1, m, &cIf_1PUZjwqO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5Yupq4Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2Z3Jl4Q, 1, m, &cIf_T2Z3Jl4Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CPA0wDgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2Z3Jl4Q, 0, m, &cIf_T2Z3Jl4Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zxdeJP1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m277kHjE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_p30HvBjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m277kHjE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ZGHktbT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z8QHLMVh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_QAQ0Y3sX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4ZKm32PM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_CtSv5tJu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nM5In3hZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nM5In3hZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BXIs6Um1, 1, m, &cDelay_BXIs6Um1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wpZ46j0P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_BXIs6Um1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BXIs6Um1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZGHktbT2, 0, m, &cIf_ZGHktbT2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nM5In3hZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BXIs6Um1, 0, m, &cDelay_BXIs6Um1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wpZ46j0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BXIs6Um1, 0, m, &cDelay_BXIs6Um1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rB3tda94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fmLNPEX1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EbLo9Ww6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RLxcHSg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kQxb7aua_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xsHASD6W_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kQxb7aua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZGHktbT2, 1, m, &cIf_ZGHktbT2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xsHASD6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CtSv5tJu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_EbLo9Ww6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QAQ0Y3sX, 0, m, &cIf_QAQ0Y3sX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fmLNPEX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QAQ0Y3sX, 1, m, &cIf_QAQ0Y3sX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4ZKm32PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FkxRkBNl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Z8QHLMVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FkxRkBNl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ss3IDaEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mk8sY0FJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_rR8kFG4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CIgg9de6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_c6ChqxWZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_A9wqZKPO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_A9wqZKPO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HIol2BIL, 1, m, &cDelay_HIol2BIL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xmr5BhNk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_HIol2BIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HIol2BIL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ss3IDaEo, 0, m, &cIf_ss3IDaEo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_A9wqZKPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HIol2BIL, 0, m, &cDelay_HIol2BIL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xmr5BhNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HIol2BIL, 0, m, &cDelay_HIol2BIL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NBOQF80B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zmZTfyvT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rtfW4yFt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_m7MdU58P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B6C7VjLi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j8q5iX53_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_B6C7VjLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ss3IDaEo, 1, m, &cIf_ss3IDaEo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_j8q5iX53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c6ChqxWZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zmZTfyvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rR8kFG4Z, 1, m, &cIf_rR8kFG4Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rtfW4yFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rR8kFG4Z, 0, m, &cIf_rR8kFG4Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CIgg9de6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bu19A7MV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_mk8sY0FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bu19A7MV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_SKJyFIf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4ZMGW6XC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ashvqBEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_868lhcjF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tList7yF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_I5Sw18vb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_I5Sw18vb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wBMWUAya, 1, m, &cDelay_wBMWUAya_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LaQCl3A3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wBMWUAya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wBMWUAya, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SKJyFIf6, 0, m, &cIf_SKJyFIf6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_I5Sw18vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wBMWUAya, 0, m, &cDelay_wBMWUAya_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LaQCl3A3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wBMWUAya, 0, m, &cDelay_wBMWUAya_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dfAbWj9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_flnm0r8B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ThXvZIyE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fPuEI7yM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ba8iiv0R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bonbJAsy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ba8iiv0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SKJyFIf6, 1, m, &cIf_SKJyFIf6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bonbJAsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tList7yF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_flnm0r8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ashvqBEk, 1, m, &cIf_ashvqBEk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ThXvZIyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ashvqBEk, 0, m, &cIf_ashvqBEk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_868lhcjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tOuRs9kN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4ZMGW6XC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tOuRs9kN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_9cMjPQbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_K8p6JJvJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BfHCpLYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kZEwfElr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_y8iOfj5h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SseIApYa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SseIApYa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NX2cGOzM, 1, m, &cDelay_NX2cGOzM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usQwxK5w_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_NX2cGOzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NX2cGOzM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9cMjPQbp, 0, m, &cIf_9cMjPQbp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SseIApYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NX2cGOzM, 0, m, &cDelay_NX2cGOzM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_usQwxK5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NX2cGOzM, 0, m, &cDelay_NX2cGOzM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mTxZN5oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YdUWnjuw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bTEVn0pb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ny6995VQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JzEjtz1h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i8CcPDqf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_i8CcPDqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_y8iOfj5h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JzEjtz1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9cMjPQbp, 1, m, &cIf_9cMjPQbp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YdUWnjuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BfHCpLYZ, 1, m, &cIf_BfHCpLYZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bTEVn0pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BfHCpLYZ, 0, m, &cIf_BfHCpLYZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kZEwfElr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_grijgBH0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_K8p6JJvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_grijgBH0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_eoco4iaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rNxEvKiD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7GZGFOLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JBLAHUX0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3mavi0go_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TUKjNyuN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TUKjNyuN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rdzqxbVj, 1, m, &cDelay_rdzqxbVj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xq1P0kvg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_rdzqxbVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rdzqxbVj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eoco4iaO, 0, m, &cIf_eoco4iaO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TUKjNyuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rdzqxbVj, 0, m, &cDelay_rdzqxbVj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Xq1P0kvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rdzqxbVj, 0, m, &cDelay_rdzqxbVj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qTZC8kmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pawkPtBf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M002xNV0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VGeIm0kl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N8K3qOZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08qQqlR2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_08qQqlR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3mavi0go_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_N8K3qOZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eoco4iaO, 1, m, &cIf_eoco4iaO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_M002xNV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7GZGFOLd, 0, m, &cIf_7GZGFOLd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pawkPtBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7GZGFOLd, 1, m, &cIf_7GZGFOLd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JBLAHUX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6SGdDRsY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rNxEvKiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6SGdDRsY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_HgWi07nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lzy5yHvE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_CaEE9KF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_m3DqOR63_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bUTlTGqw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WAfjntCO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WAfjntCO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZljG7yEF, 1, m, &cDelay_ZljG7yEF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IRXqaHlo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ZljG7yEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZljG7yEF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HgWi07nZ, 0, m, &cIf_HgWi07nZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WAfjntCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZljG7yEF, 0, m, &cDelay_ZljG7yEF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IRXqaHlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZljG7yEF, 0, m, &cDelay_ZljG7yEF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BRI26s5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IqAC3nO6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W6JqTZ4d_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LmUenI7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B2l7hnwc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vzaDiOeu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vzaDiOeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bUTlTGqw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_B2l7hnwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HgWi07nZ, 1, m, &cIf_HgWi07nZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W6JqTZ4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CaEE9KF5, 0, m, &cIf_CaEE9KF5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IqAC3nO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CaEE9KF5, 1, m, &cIf_CaEE9KF5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_m3DqOR63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CXwqNeXC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lzy5yHvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CXwqNeXC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_n9H65p91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_NRH75pzJ_sendMessage(_c, 0, m);
  cMsg_DuPvXrGG_sendMessage(_c, 0, m);
  cMsg_CfTB0H6s_sendMessage(_c, 0, m);
  cMsg_jY6gES2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_nZwJQBuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_NRH75pzJ_sendMessage(_c, 0, m);
  cMsg_lw5BSaff_sendMessage(_c, 0, m);
  cMsg_xWMCTmR2_sendMessage(_c, 0, m);
  cMsg_nsdA8DPL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_EEjfcewk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_O21buD1e_sendMessage(_c, 0, m);
  cMsg_lw5BSaff_sendMessage(_c, 0, m);
  cMsg_jY6gES2C_sendMessage(_c, 0, m);
  cMsg_8R8qpx5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DkFWRrye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_O21buD1e_sendMessage(_c, 0, m);
  cMsg_CvLMqOn1_sendMessage(_c, 0, m);
  cMsg_CfTB0H6s_sendMessage(_c, 0, m);
  cMsg_YvpNTjZc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_D6C9y4Tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_E0kM1vTt_sendMessage(_c, 0, m);
  cMsg_nsdA8DPL_sendMessage(_c, 0, m);
  cMsg_5Y00CCZd_sendMessage(_c, 0, m);
  cMsg_CfTB0H6s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CL7aH9XX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_E0kM1vTt_sendMessage(_c, 0, m);
  cMsg_YvpNTjZc_sendMessage(_c, 0, m);
  cMsg_lw5BSaff_sendMessage(_c, 0, m);
  cMsg_D4rTHcyS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_YhLBjQnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iutyrF6K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6y2rH5YX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YiQZh8I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iutyrF6K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6y2rH5YX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0kjjnRls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NFddaLx6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8RyxAJUD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kitqvpd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NFddaLx6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8RyxAJUD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qgdQNQFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S60xmEQN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1Ni0Aie2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zINS4Ymj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S60xmEQN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1Ni0Aie2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NRH75pzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_YhLBjQnF_sendMessage(_c, 0, m);
  cMsg_kitqvpd3_sendMessage(_c, 0, m);
  cMsg_zINS4Ymj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_O21buD1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_YiQZh8I1_sendMessage(_c, 0, m);
  cMsg_0kjjnRls_sendMessage(_c, 0, m);
  cMsg_zINS4Ymj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_E0kM1vTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_YiQZh8I1_sendMessage(_c, 0, m);
  cMsg_kitqvpd3_sendMessage(_c, 0, m);
  cMsg_qgdQNQFn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aVqltARa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Wrmtem1l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8ny8LeZo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_F7uhjw7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Wrmtem1l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8ny8LeZo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eCJdq1Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dnShgukO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PsMJsESe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bV2ZkyvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dnShgukO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PsMJsESe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ozncp0F7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fuktE4xl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KL9vM41Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pjUanhal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fuktE4xl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KL9vM41Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lw5BSaff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_F7uhjw7W_sendMessage(_c, 0, m);
  cMsg_bV2ZkyvG_sendMessage(_c, 0, m);
  cMsg_pjUanhal_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DuPvXrGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_F7uhjw7W_sendMessage(_c, 0, m);
  cMsg_eCJdq1Lb_sendMessage(_c, 0, m);
  cMsg_ozncp0F7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CvLMqOn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_aVqltARa_sendMessage(_c, 0, m);
  cMsg_bV2ZkyvG_sendMessage(_c, 0, m);
  cMsg_ozncp0F7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_C22QGPuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ny6995VQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mTxZN5oe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pzOTPw62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ny6995VQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mTxZN5oe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_O2l9fTLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VGeIm0kl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qTZC8kmx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nHAn4H0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VGeIm0kl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qTZC8kmx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gAzDnuKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LmUenI7z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BRI26s5e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tgVqtvKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LmUenI7z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BRI26s5e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YvpNTjZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_C22QGPuO_sendMessage(_c, 0, m);
  cMsg_nHAn4H0H_sendMessage(_c, 0, m);
  cMsg_tgVqtvKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_nsdA8DPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_pzOTPw62_sendMessage(_c, 0, m);
  cMsg_O2l9fTLz_sendMessage(_c, 0, m);
  cMsg_tgVqtvKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jY6gES2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_pzOTPw62_sendMessage(_c, 0, m);
  cMsg_nHAn4H0H_sendMessage(_c, 0, m);
  cMsg_gAzDnuKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_u1JTzuaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RLxcHSg9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rB3tda94_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ucM1GMF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RLxcHSg9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rB3tda94_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lhllemiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m7MdU58P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NBOQF80B_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GZoqawtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m7MdU58P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NBOQF80B_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tNrgYdAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fPuEI7yM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dfAbWj9l_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_N5wTifbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fPuEI7yM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dfAbWj9l_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CfTB0H6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ucM1GMF7_sendMessage(_c, 0, m);
  cMsg_GZoqawtm_sendMessage(_c, 0, m);
  cMsg_N5wTifbR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xWMCTmR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ucM1GMF7_sendMessage(_c, 0, m);
  cMsg_lhllemiZ_sendMessage(_c, 0, m);
  cMsg_tNrgYdAr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_D4rTHcyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_u1JTzuaM_sendMessage(_c, 0, m);
  cMsg_lhllemiZ_sendMessage(_c, 0, m);
  cMsg_N5wTifbR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5Y00CCZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_aVqltARa_sendMessage(_c, 0, m);
  cMsg_eCJdq1Lb_sendMessage(_c, 0, m);
  cMsg_pjUanhal_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8R8qpx5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_u1JTzuaM_sendMessage(_c, 0, m);
  cMsg_GZoqawtm_sendMessage(_c, 0, m);
  cMsg_tNrgYdAr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_HfQKxZ3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DjcmioNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_8X3PkdS5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Jw678xns, 0, m, &cSlice_Jw678xns_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CyCGmRVQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Jw678xns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ec8I7bcw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ec8I7bcw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_xFTSuK4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ec8I7bcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ec8I7bcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G0sCHPJR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_SbFPg7vm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HSUDkxEp, 0, m, &cSlice_HSUDkxEp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lncRD77f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_HSUDkxEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f12HXkk2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f12HXkk2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_KoCtah1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f12HXkk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_f12HXkk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VFDhbrP6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_lncRD77f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QZsSu8Ah, 0, m, &cSlice_QZsSu8Ah_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8X3PkdS5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_QZsSu8Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NckYiJW8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NckYiJW8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_rULWSr8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NckYiJW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_NckYiJW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6AI8yAu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CyCGmRVQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OWB8ImNJ, 0, m, &cSlice_OWB8ImNJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nlCfqBMv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_OWB8ImNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UP7KmlTH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UP7KmlTH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_liiJZTgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UP7KmlTH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_UP7KmlTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dBr6dkqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_nlCfqBMv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Vv64dhFF, 0, m, &cSlice_Vv64dhFF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xMO59SX2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Vv64dhFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kGnjvW4W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kGnjvW4W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_wumONHL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kGnjvW4W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_kGnjvW4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HAL1OlEo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_bmQZo2hT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CW2NjHTo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CW2NjHTo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_e3lSyFhs, 1, m, &cDelay_e3lSyFhs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CJVZOPEg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_e3lSyFhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e3lSyFhs, m);
  cMsg_kIOhlEJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CW2NjHTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_e3lSyFhs, 0, m, &cDelay_e3lSyFhs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CJVZOPEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e3lSyFhs, 0, m, &cDelay_e3lSyFhs_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_RVXHcNnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vyq8q1bN, HV_BINOP_SUBTRACT, 0, m, &cBinop_Vyq8q1bN_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_0vwNbSCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FvpayWI3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_4opzxpGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FvpayWI3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_WKXi9TwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RVXHcNnU, 0, m, &cVar_RVXHcNnU_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_0sK5w4wG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rdjyk06N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rXxHgRcx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZJ1grsBV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Vyq8q1bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iK8K9SKe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_iK8K9SKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_P6KgSINK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_P6KgSINK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HaMZyBDw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_N1axCZtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nnv3NjsV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ybHaOknI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ybHaOknI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bJk7p8qG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Nnv3NjsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0vwNbSCa, 1, m, &cIf_0vwNbSCa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LpqfJKPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4opzxpGn, 1, m, &cIf_4opzxpGn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bJk7p8qG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0vwNbSCa, 0, m, &cIf_0vwNbSCa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HaMZyBDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4opzxpGn, 0, m, &cIf_4opzxpGn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rXxHgRcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vyq8q1bN, HV_BINOP_SUBTRACT, 1, m, &cBinop_Vyq8q1bN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Rdjyk06N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_ZJ1grsBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RVXHcNnU, 0, m, &cVar_RVXHcNnU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FvpayWI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3xpmYri3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_xMO59SX2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gldKzvQj, 0, m, &cSlice_gldKzvQj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_gldKzvQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4wKfHpYU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4wKfHpYU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_LmzjxJam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4wKfHpYU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_4wKfHpYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NIUXCOTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_uW33wTif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jClkyQnk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XQr0yMjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RF1tvn45, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_bSRInUID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TnsIxR28, 0, m, &cVar_TnsIxR28_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DjcmioNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uogaPPyu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_LCgU9a0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bmQZo2hT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_TcIn7ho6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NGFdvKpT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kIOhlEJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_05SrbTwi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NGFdvKpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_05SrbTwi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_UWophk4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_7J083Vk3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7J083Vk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U1bFCls3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_U1bFCls3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S1qk00rD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_JU3Qrley_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6FPrwrN4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BbiurFHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NkC5VASB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_79AVFyqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b66ZQ8df, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_rU3xHNMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ua9EI8iG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_k5ATjlWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NUiFwOKc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SbFPg7vm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TsonaUlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NUiFwOKc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SbFPg7vm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_xya6nr5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KnsQc73K, 0, m, &cVar_KnsQc73K_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QmRMmzij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NUiFwOKc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SbFPg7vm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gL1nKRDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NUiFwOKc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SbFPg7vm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_02SWfP1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NUiFwOKc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SbFPg7vm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_tbdeHPtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zxWubY4b, 0, m, &cVar_zxWubY4b_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JaAJ1ZqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rWSvUvJR, 0, m, &cVar_rWSvUvJR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FiDcwNqc, 0, m, &cVar_FiDcwNqc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EGziEL7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xya6nr5V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fxiJaogx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_5N3zIEKB, 0, m, &cVar_5N3zIEKB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6FPrwrN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NUiFwOKc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SbFPg7vm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_DXMXOQL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_JU3Qrley, 0, m, &cVar_JU3Qrley_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Ua9EI8iG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_20LknxBB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_UCJJferg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ueRu52EZ, 0, m, &cVar_ueRu52EZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_AACsnfBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xya6nr5V_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_KPXEMLGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zxWubY4b, 0, m, &cVar_zxWubY4b_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Geara375_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tzerhe1r, 0, m, &cVar_tzerhe1r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N5j3H27x, 0, m, &cVar_N5j3H27x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j1y9B4nM, 0, m, &cVar_j1y9B4nM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GyduUREU, 0, m, &cVar_GyduUREU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mkyLEoXc, 0, m, &cVar_mkyLEoXc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6bSfCNEI, 0, m, &cVar_6bSfCNEI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xFTSuK4Z, 0, m, &cVar_xFTSuK4Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KoCtah1a, 0, m, &cVar_KoCtah1a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rULWSr8v, 0, m, &cVar_rULWSr8v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_liiJZTgr, 0, m, &cVar_liiJZTgr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wumONHL6, 0, m, &cVar_wumONHL6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LmzjxJam, 0, m, &cVar_LmzjxJam_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L8irQR4T_sendMessage);
  cMsg_fxiJaogx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_ajHY46CJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5N3zIEKB, 0, m, &cVar_5N3zIEKB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Hb9GH1I5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rWSvUvJR, 0, m, &cVar_rWSvUvJR_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_OaBnFh5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FiDcwNqc, 0, m, &cVar_FiDcwNqc_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_VGH3vUal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RPYnKNPD, 0, m, &cVar_RPYnKNPD_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_cCvF3QOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OGjMnBvc, 0, m, &cVar_OGjMnBvc_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Ny7LPr0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_rJvL0cMO_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_e71oun4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pdUP3NX2_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NgSIIC91_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qRGERANE_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_xzrbp2d3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DkWwgKbT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HOuYU3Lb_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Bgs5Mi9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XBQXZXUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_G0sCHPJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U2lD3izh, 0, m, &cVar_U2lD3izh_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_dBr6dkqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HfQKxZ3l, 0, m, &cVar_HfQKxZ3l_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6AI8yAu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_bSRInUID_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_VFDhbrP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NOLsKhWF_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TcIn7ho6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LCgU9a0B_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_HAL1OlEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N1axCZtn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LpqfJKPi_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_NIUXCOTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UWophk4v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_WMKvA9k8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JU3Qrley, 0, m, &cVar_JU3Qrley_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_7RXa46KR, VIf(I0));
    __hv_varread_f(&sVarf_raCtatpO, VOf(Bf0));
    __hv_varread_f(&sVarf_RpZMn31x, VOf(Bf1));
    __hv_varread_f(&sVarf_B1Zq4XXh, VOf(Bf2));
    __hv_varread_f(&sVarf_qtp6Fi3G, VOf(Bf3));
    __hv_varread_f(&sVarf_e7FF7qbI, VOf(Bf4));
    __hv_varread_f(&sVarf_VnOoW83m, VOf(Bf5));
    __hv_varread_f(&sVarf_O3G8DFMS, VOf(Bf6));
    __hv_varwrite_f(&sVarf_QLiWqu70, VIf(I0));
    __hv_varread_f(&sVarf_aLINNtPN, VOf(Bf7));
    __hv_line_f(&sLine_5jcCApEf, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_iXf9228u, VOf(Bf9));
    __hv_line_f(&sLine_qm8m5gDe, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_ZIzsDeZs, VOf(Bf8));
    __hv_line_f(&sLine_unH5Myry, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_qtp6Fi3G, VIf(Bf11));
    __hv_varread_f(&sVarf_QLiWqu70, VOf(Bf11));
    __hv_line_f(&sLine_ZsYXGwkv, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_1ZCyWpVg, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_AKC5mSE6, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_e7FF7qbI, VIf(Bf10));
    __hv_line_f(&sLine_2FKyCnGO, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_FbADPKTg, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_g0YuB3kR, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_VnOoW83m, VIf(Bf10));
    __hv_line_f(&sLine_M6PvAsDo, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_7G4Uxoi1, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_mCgeeVul, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_O3G8DFMS, VIf(Bf10));
    __hv_varwrite_f(&sVarf_aLINNtPN, VIf(Bf0));
    __hv_varwrite_f(&sVarf_iXf9228u, VIf(Bf1));
    __hv_varwrite_f(&sVarf_ZIzsDeZs, VIf(Bf2));
    sEnv_process(this, &sEnv_fpIb2OSK, VIf(Bf3), &sEnv_fpIb2OSK_sendMessage);
    sEnv_process(this, &sEnv_Yqs5pbC7, VIf(I0), &sEnv_Yqs5pbC7_sendMessage);
    __hv_line_f(&sLine_jaeqO6PY, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_pPPKhrXm, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_AsEcxRWE, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_twthQ0e3, VOf(Bf3));
    __hv_line_f(&sLine_JDHzuh9z, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_raCtatpO, VIf(Bf0));
    __hv_varwrite_f(&sVarf_twthQ0e3, VIf(Bf4));
    __hv_varwrite_f(&sVarf_1UnSnOVF, VIf(Bf5));
    __hv_varwrite_f(&sVarf_AfmcOO4c, VIf(Bf6));
    __hv_varread_f(&sVarf_AfmcOO4c, VOf(Bf6));
    __hv_line_f(&sLine_opnZKI6I, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_B1Zq4XXh, VIf(Bf4));
    __hv_varread_f(&sVarf_1UnSnOVF, VOf(Bf4));
    __hv_line_f(&sLine_twfAAmBA, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_RpZMn31x, VIf(Bf4));
    __hv_varwrite_f(&sVarf_jSYWnGIk, VIf(Bf2));
    __hv_varwrite_f(&sVarf_99DQNRYX, VIf(I1));
    __hv_varread_f(&sVarf_bzolRMvT, VOf(Bf2));
    __hv_varread_f(&sVarf_GhVr3YA8, VOf(Bf4));
    __hv_varread_f(&sVarf_oAf6O6Iv, VOf(Bf0));
    __hv_varread_f(&sVarf_rHNRWURj, VOf(Bf5));
    __hv_varread_f(&sVarf_tHF9kVMD, VOf(Bf3));
    __hv_varread_f(&sVarf_oRCHDZvE, VOf(Bf6));
    __hv_varread_f(&sVarf_jquWLlyK, VOf(Bf1));
    __hv_varwrite_f(&sVarf_CwONgLc8, VIf(I1));
    __hv_varread_f(&sVarf_GXKA1aMo, VOf(Bf10));
    __hv_line_f(&sLine_grijgBH0, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_w522ofzX, VOf(Bf7));
    __hv_line_f(&sLine_6SGdDRsY, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_lJgHGFCD, VOf(Bf11));
    __hv_line_f(&sLine_CXwqNeXC, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_rHNRWURj, VIf(Bf12));
    __hv_varread_f(&sVarf_CwONgLc8, VOf(Bf12));
    __hv_line_f(&sLine_iD3Cgxy8, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_b6lp1OkZ, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_FkxRkBNl, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_tHF9kVMD, VIf(Bf9));
    __hv_line_f(&sLine_E50Yu6FV, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_h0NA9Mtq, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Bu19A7MV, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_oRCHDZvE, VIf(Bf9));
    __hv_line_f(&sLine_xAyqSPDd, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_m277kHjE, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_tOuRs9kN, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_jquWLlyK, VIf(Bf9));
    __hv_varwrite_f(&sVarf_GXKA1aMo, VIf(Bf2));
    __hv_varwrite_f(&sVarf_w522ofzX, VIf(Bf4));
    __hv_varwrite_f(&sVarf_lJgHGFCD, VIf(Bf0));
    sEnv_process(this, &sEnv_WKXi9TwH, VIf(Bf5), &sEnv_WKXi9TwH_sendMessage);
    sEnv_process(this, &sEnv_0sK5w4wG, VIf(I1), &sEnv_0sK5w4wG_sendMessage);
    __hv_line_f(&sLine_3xpmYri3, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_05SrbTwi, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_S1qk00rD, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_OFAY6Mru, VOf(Bf5));
    __hv_line_f(&sLine_RF1tvn45, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_bzolRMvT, VIf(Bf2));
    __hv_varwrite_f(&sVarf_OFAY6Mru, VIf(Bf3));
    __hv_varwrite_f(&sVarf_2Olaf5HQ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_cl17mMD4, VIf(Bf1));
    __hv_varread_f(&sVarf_cl17mMD4, VOf(Bf1));
    __hv_line_f(&sLine_uogaPPyu, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_oAf6O6Iv, VIf(Bf3));
    __hv_varread_f(&sVarf_2Olaf5HQ, VOf(Bf3));
    __hv_line_f(&sLine_jClkyQnk, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_GhVr3YA8, VIf(Bf3));
    __hv_varwrite_f(&sVarf_6HbaqL7L, VIf(Bf0));
    __hv_varread_f(&sVarf_99DQNRYX, VOf(Bf0));
    __hv_line_f(&sLine_b66ZQ8df, VOf(Bf3));
    __hv_varread_f(&sVarf_6HbaqL7L, VOf(Bf2));
    __hv_line_f(&sLine_NkC5VASB, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_7RXa46KR, VOf(Bf2));
    __hv_varread_f(&sVarf_jSYWnGIk, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
